@@ -4,6 +4,7 @@
 ##' formats for authoring and submitting articles to Journal of Data Science
 ##' (JDS).
 ##'
-##' @docType package
-##' @name jds.rmd-package
-NULL
+##' @name jds.rmd
+##' @aliases jds.rmd-package
+##' @keywords internal
+"_PACKAGE"
